@@ -13,6 +13,11 @@ class DataType(IntEnum):
     PAGE_VIEW = 4
     USER_AGENT = 5
     ASSIGNED_VARIATION = 6
+    COOKIE = 7
+    OPERATING_SYSTEM = 8
+    GEOLOCATION = 9
+    PAGE_VIEW_VISIT = 10
+    VISITOR_VISITS = 11
 
 
 class BaseData:
