@@ -1,6 +1,6 @@
 """User Agent data"""
 
-from kameleoon.data.data import Data
+from kameleoon.data.data import Data, DataType
 
 
 # pylint: disable=W0223,W0231
@@ -15,11 +15,17 @@ class UserAgent(Data):
         .. code-block:: python3
                 kameleoon_client.add_data(visitor_code, UserAgent('TestUserAgent'))
         """
-        self.value = value
+        super().__init__()
+        self.__value = value
 
-    def get_value(self) -> str:
+    @property
+    def value(self) -> str:
         """
         return user agent value
         :return:
         """
-        return self.value
+        return self.__value
+
+    @property
+    def data_type(self) -> DataType:
+        return DataType.USER_AGENT
